@@ -41,6 +41,12 @@
             deleteButtonHandler(inline.find("a." + options.deleteCssClass), options);
         });
     };
+
+    getFormIndex = function(elem, options, regex) {
+        var formIndex = elem.find("[id^='id_" + options.prefix + "']").attr('id');
+        if (!formIndex) { return -1; }
+        return parseInt(regex.exec(formIndex)[1], 10);
+    }
     
     updateFormIndex = function(elem, options, replace_regex, replace_with) {
         elem.find(':input,span,table,iframe,label,a,ul,p,img,div').each(function() {
@@ -85,7 +91,7 @@
         var addButtons = elem.find("a." + options.addCssClass);
         // hide add button in case we've hit the max, except we want to add infinitely
         if ((maxForms.val() !== '') && (maxForms.val()-totalForms.val()) <= 0) {
-            hideAddBottons(elem, options);
+            hideAddButtons(elem, options);
         }
     };
     
@@ -116,7 +122,7 @@
             totalForms.val(index + 1);
             // hide add button in case we've hit the max, except we want to add infinitely
             if ((maxForms.val() !== 0) && (maxForms.val() !== "") && (maxForms.val() - totalForms.val()) <= 0) {
-                hideAddBottons(inline, options);
+                hideAddButtons(inline, options);
             }
             // callback
             options.onAfterAdded(form);
@@ -128,24 +134,26 @@
             var inline = elem.parents(".grp-group"),
                 form = $(this).parents("." + options.formCssClass).first(),
                 totalForms = inline.find("#id_" + options.prefix + "-TOTAL_FORMS"),
-                maxForms = inline.find("#id_" + options.prefix + "-MAX_NUM_FORMS");
+                maxForms = inline.find("#id_" + options.prefix + "-MAX_NUM_FORMS"),
+                re = /-(\d+)-/,
+                removedFormIndex = getFormIndex(form, options, re);
             // callback
             options.onBeforeRemoved(form);
             // remove form
             form.remove();
             // update total forms
-            var index = parseInt(totalForms.val(), 10);
-            totalForms.val(index - 1);
+            totalForms.val(parseInt(totalForms.val(), 10) - 1);
             // show add button in case we've dropped below max
             if ((maxForms.val() !== 0) && (maxForms.val() - totalForms.val()) > 0) {
                 showAddButtons(inline, options);
             }
-            // update form index (for all forms)
-            var re = /-\d+-/g,
-                i = 0;
+            // update form index (only forms with a higher index than the removed form)
             inline.find("." + options.formCssClass).each(function() {
-                updateFormIndex($(this), options, re, "-" + i + "-");
-                i++;
+                var form = $(this),
+                    formIndex = getFormIndex(form, options, re);
+                if (formIndex > removedFormIndex) {
+                    updateFormIndex(form, options, re, "-" + (formIndex - 1) + "-");
+                }
             });
             // callback
             options.onAfterRemoved(inline);
@@ -172,7 +180,7 @@
         });
     };
     
-    hideAddBottons = function(elem, options) {
+    hideAddButtons = function(elem, options) {
         var addButtons = elem.find("a." + options.addCssClass);
         addButtons.hide().parents('.grp-add-item').hide();
     };
