@@ -68,7 +68,7 @@
             app_label: grappelli.get_app_label(elem),
             model_name: grappelli.get_model_name(elem)
         }, function(data) {
-            if (data[0].label == "") {
+            if (data[0].label === "") {
                 text.hide();
             } else {
                 text.show();
